==> svm-1.0.0-rc8-sources.jar: com/oracle/svm/core/graal/nodes/KillMemoryNode.java <==
/*
 * Copyright (c) 2013, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.graal.nodes;

import org.graalvm.compiler.core.common.type.StampFactory;
import org.graalvm.compiler.graph.NodeClass;
import org.graalvm.compiler.nodeinfo.InputType;
import org.graalvm.compiler.nodeinfo.NodeCycles;
import org.graalvm.compiler.nodeinfo.NodeInfo;
import org.graalvm.compiler.nodeinfo.NodeSize;
import org.graalvm.compiler.nodes.FixedWithNextNode;
import org.graalvm.compiler.nodes.memory.MemoryCheckpoint;
import org.graalvm.compiler.nodes.spi.LIRLowerable;
import org.graalvm.compiler.nodes.spi.NodeLIRBuilderTool;
import org.graalvm.word.LocationIdentity;

@NodeInfo(allowedUsageTypes = InputType.Memory, cycles = NodeCycles.CYCLES_0, size = NodeSize.SIZE_0)
public class KillMemoryNode extends FixedWithNextNode implements MemoryCheckpoint.Single, LIRLowerable {
    public static final NodeClass<KillMemoryNode> TYPE = NodeClass.create(KillMemoryNode.class);

    protected final LocationIdentity killedIdentity;

    protected KillMemoryNode(LocationIdentity killedIdentity) {
        super(TYPE, StampFactory.forVoid());
        this.killedIdentity = killedIdentity;
    }

    @Override
    public LocationIdentity getLocationIdentity() {
        return killedIdentity;
    }

    @Override
    public void generate(NodeLIRBuilderTool generator) {
        // No code to generate.
    }

    @NodeIntrinsic
    public static native void killMemory(@ConstantNodeParameter LocationIdentity killedIdentity);
}

==> svm-19.3.6-sources.jar: com/oracle/svm/core/graal/nodes/KillMemoryNode.java <==
/*
 * Copyright (c) 2013, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.graal.nodes;

import org.graalvm.compiler.core.common.type.StampFactory;
import org.graalvm.compiler.graph.NodeClass;
import org.graalvm.compiler.nodeinfo.InputType;
import org.graalvm.compiler.nodeinfo.NodeCycles;
import org.graalvm.compiler.nodeinfo.NodeInfo;
import org.graalvm.compiler.nodeinfo.NodeSize;
import org.graalvm.compiler.nodes.FixedWithNextNode;
import org.graalvm.compiler.nodes.memory.MemoryCheckpoint;
import org.graalvm.compiler.nodes.spi.LIRLowerable;
import org.graalvm.compiler.nodes.spi.NodeLIRBuilderTool;
import org.graalvm.word.LocationIdentity;

@NodeInfo(allowedUsageTypes = InputType.Memory, cycles = NodeCycles.CYCLES_0, size = NodeSize.SIZE_0)
public class KillMemoryNode extends FixedWithNextNode implements MemoryCheckpoint.Single, LIRLowerable {
    public static final NodeClass<KillMemoryNode> TYPE = NodeClass.create(KillMemoryNode.class);

    protected final LocationIdentity killedIdentity;

    protected KillMemoryNode(LocationIdentity killedIdentity) {
        super(TYPE, StampFactory.forVoid());
        this.killedIdentity = killedIdentity;
    }

    @Override
    public LocationIdentity getKilledLocationIdentity() {
        return killedIdentity;
    }

    @Override
    public void generate(NodeLIRBuilderTool generator) {
        // No code to generate.
    }

    @NodeIntrinsic
    public static native void killMemory(@ConstantNodeParameter LocationIdentity killedIdentity);
}
